.. btclib documentation master file.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to btclib's documentation
=================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   README <readme_link.md>
   PYTHON PACKAGE <modules>
   CONTRIBUTING <contributing_link.md>
   SECURITY <security_link.md>
   HISTORY <history_link.md>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
